@@ -5,35 +5,26 @@
 #'
 #' @param data A dataset
 #' @param n Weights variable for count data
-#' @param target Target variable (0/1 or FALSE/TRUE)
-#' @param targetpct Plot variable as target% (FALSE/TRUE)
+#' @param target Target variable (0/1 or `FALSE`/`TRUE`)
+#' @param targetpct Plot variable as target% (`FALSE`/`TRUE`)
 #' @param split Alternative to targetpct (split = !targetpct)
 #' @param output_file Filename of the html report
 #' @param output_dir Directory where to save the html report
-#' @import rmarkdown
 #' @examples
-#' if (rmarkdown::pandoc_available("1.12.3"))   {
-#'   report(iris, output_dir = tempdir())
-#' }
+#' if (rmarkdown::pandoc_available("1.12.3")) {
+#'  report(iris, output_dir = tempdir())
+#'  }
 #' @export
 
 report <- function(data, n, target, targetpct, split, output_file, output_dir)  {
 
+  check_data_frame_non_empty(data)
   # pandoc must be available to generate report
   # if RStudio is used, pandoc should be available
-  if (!rmarkdown::pandoc_available())  {
-    stop("no report generated because pandoc is not available")
-  }
-
-  # pandoc version 1.12.3 or higher must be available
-  if (!rmarkdown::pandoc_version() >= "1.12.3")  {
-    stop("no report generated because pandoc version >= 1.12.3 needed")
-  }
+  rmarkdown::pandoc_available(version = "1.12.3", error = TRUE)
 
   # output_dir must be defined
-  if(missing(output_dir)) {
-    stop("output_dir must be defined")
-  }
+  rlang::check_required(output_dir)
 
   # parameter target
   if(!missing(target))  {
@@ -63,43 +54,46 @@ report <- function(data, n, target, targetpct, split, output_file, output_dir)
 
   # check if output-file has .html extension
   # if not, add it!
-  if (!missing(output_file)) {
-    len <- nchar(output_file)
-    if (tolower(substr(output_file, len-4, len)) != ".html")  {
-      output_file <- paste0(output_file, ".html")
+  output_file <- if (!missing(output_file)) {
+    if (!identical(tools::file_ext(output_file), "html"))  {
+      paste0(output_file, ".html")
+    } else {
+      output_file
+    }
+    } else if (is.na(target_text)) {
+    "report_variable.html"
+    } else {
+    "report_target_split.html"
     }
-  } # if
 
-  # report variables
-  if(is.na(target_text) & is.na(n_txt))  {
-    input_file <- system.file("extdata", "template_report_variable.Rmd", package="explore")
-    if (missing(output_file)) {output_file = "report_variable.html"}
-      rmarkdown::render(input = input_file,
+
+  report <- if (is.na(target_text) && is.na(n_txt))  {
+    # report variables
+    input_file <- system.file("extdata", "template_report_variable.Rmd", package = "explore")
+    rmarkdown::render(input = input_file,
                         output_file = output_file,
                         output_dir = output_dir,
                         intermediates_dir = output_dir,
                         clean = TRUE
     )
 
-  # report variables + n
-  } else if(is.na(target_text) & !is.na(n_txt))  {
+  } else if(is.na(target_text) && !is.na(n_txt))  {
+    # report variables + n
     input_file <- system.file("extdata", "template_report_variable_n.Rmd", package="explore")
-    if (missing(output_file)) {output_file = "report_variable.html"}
-      var_name_n <- n_txt
-      rmarkdown::render(input = input_file,
+    var_name_n <- n_txt
+    rmarkdown::render(input = input_file,
                         output_file = output_file,
                         output_dir = output_dir,
                         intermediates_dir = output_dir,
                         clean = TRUE
-      )
+                      )
 
-      # report target + n
-  } else if(!is.na(target_text) & !is.na(n_txt))  {
+  } else if(!is.na(target_text) && !is.na(n_txt))  {
+    # report target + n
     input_file <- system.file("extdata", "template_report_target_split_n.Rmd", package="explore")
-    if (missing(output_file)) {output_file = "report_target_split.html"}
-      var_name_n <- n_txt
-      var_name_target <- target_text  # needed in report template
-      rmarkdown::render(input = input_file,
+    var_name_n <- n_txt
+    var_name_target <- target_text  # needed in report template
+    rmarkdown::render(input = input_file,
                         output_file = output_file,
                         output_dir = output_dir,
                         intermediates_dir = output_dir,
@@ -107,9 +101,8 @@ report <- function(data, n, target, targetpct, split, output_file, output_dir)
     )
 
     # report target with split
-  } else if(split == TRUE)  {
-    input_file <- system.file("extdata", "template_report_target_split.Rmd", package="explore")
-    if (missing(output_file)) {output_file = "report_target_split.html"}
+  } else if(split)  {
+    input_file <- system.file("extdata", "template_report_target_split.Rmd", package = "explore")
     var_name_target <- target_text  # needed in report template
     rmarkdown::render(input = input_file,
                       output_file = output_file,
@@ -120,7 +113,7 @@ report <- function(data, n, target, targetpct, split, output_file, output_dir)
 
     # report target with percent
   } else {
-    input_file <- system.file("extdata", "template_report_target_pct.Rmd", package="explore")
+    input_file <- system.file("extdata", "template_report_target_pct.Rmd", package = "explore")
     if (missing(output_file)) {output_file = "report_target.html"}
     var_name_target <- target_text # needed in report template
     rmarkdown::render(input = input_file,
@@ -129,7 +122,8 @@ report <- function(data, n, target, targetpct, split, output_file, output_dir)
                       intermediates_dir = output_dir,
                       clean = TRUE
     )
-  } # if
+  }
+  invisible(report)# if
 } # report
 
 #' Generate a notebook
@@ -140,22 +134,20 @@ report <- function(data, n, target, targetpct, split, output_file, output_dir)
 #'
 #' @param output_file Filename of the html report
 #' @param output_dir Directory where to save the html report
-#' @examples
+#' @examplesIf rmarkdown::pandoc_available()
 #' create_notebook_explore(output_file = "explore.Rmd", output_dir = tempdir())
 #' @export
 
 create_notebook_explore <- function(output_file = "notebook-explore.Rmd", output_dir) {
 
   # output_dir must be defined
-  if(missing(output_dir)) {
-    stop("output_dir must be defined")
-  }
+  rlang::check_required(output_dir)
 
   # check if output-file has .Rmd extension
   # if not, add it!
   if (!missing(output_file)) {
     len <- nchar(output_file)
-    if (tolower(substr(output_file, len-4, len)) != ".rmd")  {
+    if (tolower(substr(output_file, len-3, len)) != ".rmd")  {
       output_file <- paste0(output_file, ".Rmd")
     }
   } # if
