@@ -8,7 +8,7 @@
 #' encrypt("hello world")
 #' @export
 
-encrypt<-function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)  {
+encrypt <- function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)  {
   old=paste(codeletters,collapse="")
   new=paste(c(codeletters[(shift+1):nchar(old)],codeletters[1:shift]),collapse="")
   return (chartr(old,new,text))
@@ -24,7 +24,7 @@ encrypt<-function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)
 #' decrypt("zw336 E693v")
 #' @export
 
-decrypt<-function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)  {
+decrypt <- function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)  {
   old=paste(codeletters,collapse="")
   new=paste(c(codeletters[(shift+1):nchar(old)],codeletters[1:shift]),collapse="")
   return (chartr(new,old,text))
@@ -40,8 +40,6 @@ decrypt<-function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)
 #' @param min_prop Minimum proportion of one of the target categories
 #' @param seed Seed for random number generator
 #' @return Data
-#' @import rlang
-#' @import dplyr
 #' @examples
 #' iris$is_versicolor <- ifelse(iris$Species == "versicolor", 1, 0)
 #' balanced <- balance_target(iris, target = is_versicolor, min_prop = 0.5)
@@ -51,18 +49,11 @@ decrypt<-function (text, codeletters=c(toupper(letters),letters,0:9), shift=18)
 balance_target <- function(data, target, min_prop = 0.1, seed) {
 
   # check if parameters are missing
-  if (missing(data))  {
-    stop("data is missing")
-  }
-
-  if (missing(target))  {
-    stop("target is missing")
-  }
+  check_data_frame_non_empty(data)
+  rlang::check_required(target)
 
   # check if min_prop has a meaningful value
-  if (min_prop < 0 | min_prop > 1)  {
-    stop("min_prop must be a value between 0 and 1")
-  }
+  check_number_decimal(min_prop, min = 0, max = 1)
 
   # tidy eval for target
   target_quo <- enquo(target)
@@ -95,14 +86,14 @@ balance_target <- function(data, target, min_prop = 0.1, seed) {
 
     # sampling
     data_minClass <- tmp_min %>%
-      dplyr::sample_n(minClass)
+      dplyr::slice_sample(n = minClass)
     data_maxClass <- tmp_max %>%
-      dplyr::sample_n(maxClass)
+      dplyr::slice_sample(n = maxClass)
 
     # mix it up
     data <- rbind(data_minClass, data_maxClass)
     if (!missing(seed)) {set.seed(seed)}
-    data <- data %>% dplyr::sample_n(nrow(data))
+    data <- data %>% dplyr::slice_sample(n = nrow(data))
 
     # return
     data
@@ -112,30 +103,23 @@ balance_target <- function(data, target, min_prop = 0.1, seed) {
 #' Weight target variable
 #'
 #' Create weights for the target variable in your dataset
-#' so that are equal weiths for target = 0 and target = 1.
+#' so that are equal weights for target = 0 and target = 1.
 #' Target must be 0/1, FALSE/TRUE ore no/yes
 #'
 #' @param data A dataset
 #' @param target Target variable (0/1, TRUE/FALSE, yes/no)
 #' @return Weights for each observation (as a vector)
-#' @import rlang
-#' @import dplyr
 #' @examples
 #' iris$is_versicolor <- ifelse(iris$Species == "versicolor", 1, 0)
 #' weights <- weight_target(iris, target = is_versicolor)
-#' summary(weights)
+#' versicolor <- iris$is_versicolor
+#' table(versicolor, weights)
 #' @export
 
 weight_target <- function(data, target) {
-
   # check if parameters are missing
-  if (missing(data))  {
-    stop("data is missing")
-  }
-
-  if (missing(target))  {
-    stop("target is missing")
-  }
+  check_data_frame_non_empty(data)
+  rlang::check_required(target)
 
   # tidy eval for target
   target_quo <- enquo(target)
@@ -157,7 +141,7 @@ weight_target <- function(data, target) {
   weights = ifelse(data[[target_txt]] == names(minClass),
                    max(observed_prop)/min(observed_prop), 1)
 
-  # return weigthts
+  # return weights
   return(weights)
 
 } # weight_target
@@ -171,7 +155,6 @@ weight_target <- function(data, target) {
 #' @param size Text-size
 #' @param color Text-color
 #' @return Plot
-#' @importFrom graphics plot text
 #' @examples
 #' plot_text("hello", size = 2, color = "red")
 #' @export
@@ -189,9 +172,6 @@ plot_text <- function(text="hello world", size=1.2, color="black")  {
 #' @param var Variable
 #' @param info Text to plot
 #' @return Plot (ggplot)
-#' @import rlang
-#' @import dplyr
-#' @import ggplot2
 
 plot_var_info <- function(data, var, info = "")  {
 
@@ -222,7 +202,6 @@ plot_var_info <- function(data, var, info = "")  {
 #'
 #' @param border Draw a border?
 #' @return Base plot
-#''@importFrom graphics legend par plot
 #' @examples
 #' plot_legend_targetpct(border = TRUE)
 #' @export
@@ -249,7 +228,7 @@ plot_legend_targetpct <- function(border = TRUE) {
 #'
 #' @param number A number (integer or real)
 #' @param digits Number of digits
-#' @return Formated number as text
+#' @return Formatted number as text
 #' @examples
 #' format_num_space(5500, digits = 2)
 #' @export
@@ -275,7 +254,7 @@ format_num_space <- function(number = 0, digits = 1)   {
 #'
 #' @param number A number (integer or real)
 #' @param digits Number of digits
-#' @return Formated number as text
+#' @return Formatted number as text
 #' @examples
 #' format_num_kMB(5500, digits = 2)
 #' @export
@@ -309,7 +288,7 @@ format_num_kMB <- function(number = 0, digits = 1)   {
 #'
 #' @param number A number (integer or real)
 #' @param digits Number of digits
-#' @return Formated number as text
+#' @return Formatted number as text
 #' @examples
 #' format_num_kMB(5500, digits = 2)
 #' @export
@@ -387,10 +366,10 @@ replace_na_with <- function(data, var_name, with)  {
 
 #' Format type description
 #'
-#' Format type description of varable to 3 letters (int|dbl|lgl|chr|dat)
+#' Format type description of variable to 3 letters (int|dbl|lgl|chr|dat)
 #'
 #' @param type Type description ("integer", "double", "logical", character", "date")
-#' @return Formated type description (int|dbl|lgl|chr|dat)
+#' @return Formatted type description (int|dbl|lgl|chr|dat)
 #' @examples
 #' format_type(typeof(iris$Species))
 #' @export
@@ -454,13 +433,13 @@ get_type <- function(var)  {
 } # get_type
 
 
-#' Return if variable is categorial or nomerical
+#' Return if variable is categorical or numerical
 #'
-#' Guess if variable is categorial or numerical based on name, type and values of variable
+#' Guess if variable is categorical or numerical based on name, type and values of variable
 #'
 #' @param var A vector (dataframe column)
 #' @param descr A description of the variable (optional)
-#' @return "cat" (categorial), "num" (numerical) or "oth" (other)
+#' @return "cat" (categorical), "num" (numerical) or "oth" (other)
 #' @examples
 #' guess_cat_num(iris$Species)
 #' @export
@@ -650,9 +629,7 @@ get_var_buckets <- function(data, bucket_size = 100,
 data_dict_md <- function(data, title = "", description = NA, output_file = "data_dict.md", output_dir)  {
 
   # output_dir must be defined
-  if(missing(output_dir)) {
-    stop("output_dir must be defined")
-  }
+  check_string(output_dir)
 
   # describe data
   d <- data %>% describe()
@@ -710,7 +687,6 @@ data_dict_md <- function(data, title = "", description = NA, output_file = "data
 #'
 #' @param text text string
 #' @return text string
-#' @import dplyr
 #' @examples
 #' simplify_text(" Hello  World !, ")
 #' @export
@@ -738,7 +714,6 @@ simplify_text <- function(text)  {
 #'
 #' @param x numeric vector (to be rescaled)
 #' @return vector with values between 0 and 1
-#' @import dplyr
 #' @examples
 #' rescale01(0:10)
 #' @export
@@ -763,14 +738,14 @@ rescale01 <- function(x)  {
 #' @param min_val All values < min_val are converted to min_val (var numeric or character)
 #' @param max_val All values > max_val are converted to max_val (var numeric or character)
 #' @param max_cat Maximum number of different factor levels for categorical variable (if more, .OTHER is added)
-#' @param rescale01 Rescale into value between 0 and 1 (var must be numeric)
-#' @param simplify_text if TRUE, a character variable is simplified (trim, upper, ...)
+#' @param rescale01 IF TRUE, value is rescaled between 0 and 1 (var must be numeric)
+#' @param simplify_text If TRUE, a character variable is simplified (trim, upper, ...)
 #' @param name New name of variable (as string)
 #' @return Dataset
-#' @import rlang
-#' @import dplyr
 #' @examples
-#' clean_var(iris, Sepal.Width, max_val = 3.5, name = "sepal_width")
+#' library(magrittr)
+#' iris %>% clean_var(Sepal.Width, max_val = 3.5, name = "sepal_width") %>% head()
+#' iris %>% clean_var(Sepal.Width, rescale01 = TRUE) %>% head()
 #' @export
 
 clean_var <- function(data, var, na = NA, min_val = NA, max_val = NA, max_cat = NA, rescale01 = FALSE, simplify_text = FALSE, name = NA)  {
@@ -822,7 +797,10 @@ clean_var <- function(data, var, na = NA, min_val = NA, max_val = NA, max_cat =
     n_var_cat <- length(levels(data[[var_txt]]))
 
     # add level for NA (if in data)
-    data[[var_txt]] <- forcats::fct_explicit_na(data[[var_txt]], na_level = ".NA")
+    if (any(is.na(data[[var_txt]])))  {
+      levels(data[[var_txt]]) <- c(levels(data[[var_txt]]), ".NA")
+      data[[var_txt]] <- ifelse(is.na(data[[var_txt]]), ".NA", data[[var_txt]])
+    }
 
     # keep max. different levels
     if (n_var_cat > max_cat)  {
@@ -843,7 +821,7 @@ clean_var <- function(data, var, na = NA, min_val = NA, max_val = NA, max_cat =
   # rename variable
   if (!is.na(name))  {
     var_names <- colnames(data)
-    if (name %in% var_names & name != var_txt)  {
+    if (name %in% var_names && name != var_txt)  {
       warning("variable ", name, " already exists in data. Did not rename, select other name!")
     } else {
       colnames(data)[colnames(data) == var_txt] <- name
@@ -862,7 +840,6 @@ clean_var <- function(data, var, na = NA, min_val = NA, max_val = NA, max_cat =
 #' @param data A dataset
 #' @param ... Other parameters passed to count()
 #' @return Dataset
-#' @import dplyr
 #' @examples
 #' count_pct(iris, Species)
 #' @export
